@@ -459,6 +459,12 @@ extern int fpstore_errata_debug;
 
 extern int fix_b2bst;
 
+extern int sparc_fix_gr712rc;
+
+extern int sparc_fix_ut700;
+
+extern int sparc_fix_tn0013;
+
 /* Nonzero means give `double' the same size as `float'.  */
 
 extern int flag_short_double;
